@@ -1,4 +1,4 @@
 module C where
 
 name :: String
-name = "Samantha"
+name = "SamanthaC"
