@@ -37,11 +37,7 @@ check title expected got
 -- See Note [Adding a language extension] in compiler/GHC/Driver/Session.hs.
 expectedGhcOnlyExtensions :: [String]
 expectedGhcOnlyExtensions =
-    [ "RelaxedLayout"
-    , "AlternativeLayoutRule"
-    , "AlternativeLayoutRuleTransitional"
-    , "OverloadedRecordUpdate"
-    , "DeepSubsumption"
+    [ "DeepSubsumption"
     ]
 
 expectedCabalOnlyExtensions :: [String]
