@@ -17,15 +17,13 @@ import GHC.Utils.Outputable                 ( Outputable, renderWithContext, ppr
 import GHC.Iface.Ext.Binary
 import GHC.Iface.Ext.Types
 import GHC.Iface.Ext.Utils
-
+ 
 import GHC.Driver.Session
 import GHC.SysTools
 
 makeNc :: IO NameCache
-makeNc = do
-  uniq_supply <- mkSplitUniqSupply 'z'
-  pure $ initNameCache uniq_supply []
-
+makeNc = initNameCache 'z' []
+ 
 dynFlagsForPrinting :: String -> IO DynFlags
 dynFlagsForPrinting libdir = do
   systemSettings <- initSysTools libdir
@@ -36,7 +34,7 @@ readTestHie fp = do
   libdir:_ <- getArgs
   df <- dynFlagsForPrinting libdir
   nc <- makeNc
-  hfr <- readHieFile (NCU (\f -> pure $ snd $ f nc)) fp
+  hfr <- readHieFile nc fp
   pure (df, hie_file_result hfr)
 
 render :: Outputable a => DynFlags -> a -> String
