@@ -24,6 +24,7 @@ import qualified GHC.CmmToAsm.Reg.Graph.Stats as Color
 import qualified GHC.CmmToAsm.Reg.Linear.Base as Linear
 import qualified GHC.CmmToAsm.X86.Instr as X86.Instr
 import qualified GHC.CmmToAsm.X86 as X86
+import GHC.Driver.Config.CmmToAsm
 import GHC.Driver.Main
 import GHC.Driver.Env
 import GHC.StgToCmm.CgUtils
@@ -39,14 +40,20 @@ import GHC.Unit.Module
 import GHC.Cmm.DebugBlock
 import GHC
 import GHC.Driver.Monad
+import GHC.Driver.Config.Diagnostic
 import GHC.Types.Unique.FM
 import GHC.Types.Unique.Supply
 import GHC.Driver.Session
 import GHC.Driver.Errors
 import GHC.Utils.Error
+import GHC.Utils.Logger
 import GHC.Utils.Outputable
 import GHC.Types.Basic
 import GHC.Unit.Home
+import GHC.Unit.Finder
+import GHC.Unit.Env
+import GHC.Unit.Home.ModInfo
+import GHC.Driver.Config.Finder
 
 import GHC.Data.Stream as Stream (collect, yield)
 
@@ -64,8 +71,15 @@ main = do
 
     --get a GHC context and run the tests
     runGhc (Just libdir) $ do
-        dflags0 <- fmap setOptions getDynFlags
-        setSessionDynFlags dflags0
+        dflags0 <- flip gopt_set Opt_RegsGraph <$> getDynFlags
+        --the register allocator's intermediate data
+        --structures are usually discarded
+        --(in GHC.CmmToAsm.cmmNativeGen) for performance
+        --reasons.  To prevent this we need to tell
+        --cmmNativeGen we want them printed out even
+        --though we ignore stderr in the test configuration.
+        let dflags1 = dopt_set dflags0 Opt_D_dump_asm_stats
+        setSessionDynFlags dflags1
 
         dflags <- getDynFlags
         logger <- getLogger
@@ -75,8 +89,6 @@ main = do
 
     return ()
 
-    where setOptions = (flip gopt_set) Opt_RegsGraph
-
 
 -- | TODO: Make this an IORef along the lines of Data.Unique.newUnique to add
 -- stronger guarantees a UniqSupply won't be accidentally reused
@@ -113,29 +125,29 @@ compileCmmForRegAllocStats ::
     UniqSupply ->
     IO [( Maybe [Color.RegAllocStats (Alignment, RawCmmStatics) X86.Instr.Instr]
         , Maybe [Linear.RegAllocStats])]
-compileCmmForRegAllocStats logger dflags' cmmFile ncgImplF us = do
+compileCmmForRegAllocStats logger dflags cmmFile ncgImplF us = do
     let ncgImpl = ncgImplF (initNCGConfig dflags thisMod)
     hscEnv <- newHscEnv dflags
 
     -- parse the cmm file and output any warnings or errors
     let fake_mod = mkHomeModule (hsc_home_unit hscEnv) (mkModuleName "fake")
     (warnings, errors, parsedCmm) <- parseCmmFile dflags fake_mod (hsc_home_unit hscEnv) cmmFile
-    let warningMsgs = fmap pprWarning warnings
-        errorMsgs   = fmap pprError errors
 
     -- print parser errors or warnings
-    mapM_ (printBagOfErrors logger dflags) [warningMsgs, errorMsgs]
+    let !diag_opts = initDiagOpts dflags
+    mapM_ (printMessages logger diag_opts) [warnings, errors]
 
     let initTopSRT = emptySRT thisMod
     cmmGroup <- fmap snd $ cmmPipeline hscEnv initTopSRT $ fst $ fromJust parsedCmm
 
-    rawCmms <- cmmToRawCmm logger dflags (Stream.yield cmmGroup)
+    let profile = targetProfile dflags
+    rawCmms <- cmmToRawCmm logger profile (Stream.yield cmmGroup)
 
     collectedCmms <- mconcat <$> Stream.collect rawCmms
 
     -- compile and discard the generated code, returning regalloc stats
     mapM (\ (count, thisCmm) ->
-        cmmNativeGen logger dflags thisModLoc ncgImpl
+        cmmNativeGen logger thisModLoc ncgImpl
             usb dwarfFileIds dbgMap thisCmm count >>=
                 (\(_, _, _, _, colorStats, linearStats, _) ->
                 -- scrub unneeded output from cmmNativeGen
@@ -143,13 +155,6 @@ compileCmmForRegAllocStats logger dflags' cmmFile ncgImplF us = do
                 $ zip [0.. (length collectedCmms)] collectedCmms
 
     where
-          --the register allocator's intermediate data
-          --structures are usually discarded
-          --(in AsmCodeGen.cmmNativeGen) for performance
-          --reasons.  To prevent this we need to tell
-          --cmmNativeGen we want them printed out even
-          --though we ignore stderr in the test configuration.
-          dflags = dopt_set dflags' Opt_D_dump_asm_stats
           [usa, usb, usc, usd] = take 4 . listSplitUniqSupply $ us
           -- don't need debugging information
           dwarfFileIds = emptyUFM
@@ -157,7 +162,7 @@ compileCmmForRegAllocStats logger dflags' cmmFile ncgImplF us = do
           thisMod = mkModule
                         (stringToUnit . show . uniqFromSupply $ usc)
                         (mkModuleName . show . uniqFromSupply $ usd)
-          thisModLoc = ModLocation Nothing (cmmFile ++ ".hi") (cmmFile ++ ".o") (cmmFile ++ ".hie")
+          thisModLoc = mkHiOnlyModLocation (initFinderOpts dflags) "hi" "dyn_hi" "" cmmFile
 
 
 -- | The register allocator should be able to see that each variable only
@@ -209,7 +214,7 @@ testGraphNoSpills logger dflags' path us = do
             let acc n = maybe n (++ n) in
               foldr (\(as, bs) (xs, ys) -> (acc xs as, acc ys bs)) ([], [])
 
-          dflags = dflags' { optLevel = 2 }
+          dflags = updOptLevel 2 dflags'
 
           -- discard irrelevant stats
           extractSRMs x = case x of
